@@ -237,10 +237,8 @@ class Chapter(object):
         child_folder = goal_dir / self._folder
         if not child_folder.exists():
             child_folder.mkdir(parents=True, exist_ok=True)
-        child_filename = child_folder / self._filename
-        child_filename_tex = child_folder / self._filename.replace(
-            self._fmt, "tex"
-        )
+        child_filename = self._figures_dir / f"{self._filename}.{self._fmt}"
+        child_filename_tex = child_folder / f"{self._filename}.tex"
         # fig_desc["path"] = child_filename
         fig_desc[
             "path"
